==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/SetDeactivated.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
namespace com.db4o.test {

   public class SetDeactivated {
      internal String foo;
      
      public SetDeactivated() : base() {
      }
      
      public SetDeactivated(String foo) : base() {
         this.foo = foo;
      }
      
      public void store() {
         Tester.deleteAllInstances(this);
         Tester.store(new SetDeactivated("hi"));
         Tester.commit();
      }
      
      public void test() {
         SetDeactivated sd1 = (SetDeactivated)Tester.getOne(this);
         Tester.objectContainer().deactivate(sd1, 1);
         Tester.store(sd1);
         Tester.objectContainer().purge(sd1);
         sd1 = (SetDeactivated)Tester.getOne(this);
         Tester.objectContainer().activate(sd1, 1);
         Tester.ensure(sd1.foo.Equals("hi"));
      }
   }
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/SetDeactivated.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
namespace com.db4o.test {

   public class SetDeactivated {
      internal String foo;
      
      public SetDeactivated() : base() {
      }
      
      public SetDeactivated(String foo) : base() {
         this.foo = foo;
      }
      
      public void Store() {
         Tester.DeleteAllInstances(this);
         Tester.Store(new SetDeactivated("hi"));
         Tester.Commit();
      }
      
      public void Test() {
         SetDeactivated sd1 = (SetDeactivated)Tester.GetOne(this);
         Tester.ObjectContainer().Deactivate(sd1, 1);
         Tester.Store(sd1);
         Tester.ObjectContainer().Purge(sd1);
         sd1 = (SetDeactivated)Tester.GetOne(this);
         Tester.ObjectContainer().Activate(sd1, 1);
         Tester.Ensure(sd1.foo.Equals("hi"));
      }
   }
}
